pub enum ProvisionerError {
Unsupported(String),
Capacity(String),
Auth(String),
Transport(String),
Other(String),
}Expand description
Errors returned by a CloudProvisioner.
Variants
Unsupported(String)
The requested operation or shape is not supported by this provider.
Capacity(String)
The provider could not satisfy the request due to lack of capacity.
Auth(String)
Authentication or authorization with the provider failed.
Transport(String)
A transport / IO error occurred while talking to the provider.
Other(String)
Any other error.